<?php
use CRM_Contactcats_ExtensionUtil as E;

return [
  'name' => 'ContactCategory',
  'table' => 'civicrm_contact_category',
  'class' => 'CRM_Contactcats_DAO_ContactCategory',
  'getInfo' => fn() => [
    'title' => E::ts('Contact Category'),
    'title_plural' => E::ts('Contact Categories'),
    'description' => E::ts('Stores a category for each contact'),
    'log' => FALSE,
  ],
  'getIndices' => fn() => [
    'index_category_definition_id' => [
      'fields' => [
        'category_definition_id' => TRUE,
      ],
    ],
  ],
  'getFields' => fn() => [
    'id' => [
      'title' => E::ts('ID'),
      'sql_type' => 'int unsigned',
      'input_type' => 'Number',
      'required' => TRUE,
      'description' => E::ts('Unique ID, corresponds to contact id'),
      'primary_key' => TRUE,
      'auto_increment' => TRUE,
      'input_attrs' => [
        'label' => E::ts('Contact'),
      ],
      'entity_reference' => [
        'entity' => 'Contact',
        'key' => 'id',
        'on_delete' => 'CASCADE',
      ],
    ],
    'category_definition_id' => [
      'title' => E::ts('Category Definition'),
      'sql_type' => 'int unsigned',
      'required' => FALSE,
      'default' => NULL,
      // 'input_type' => 'EntityRef',
      'input_type' => 'Select',
      'entity_reference' => [
        'entity' => 'ContactCategoryDefinition',
        'key' => 'id',
        'on_delete' => 'CASCADE',
      ],
      'pseudoconstant' => [
        'prefetch' => TRUE,
        'table' => 'civicrm_contact_category_definition',
        'key_column' => 'id',
        'label_column' => 'label',
        'name_column' => 'id',
      ],
    ],
    'next_category' => [
      'title' => E::ts('Next Category - internal use'),
      'sql_type' => 'int unsigned',
      'required' => TRUE,
      'default' => 0,
      'input_type' => 'Hidden', /* not needed to be exposed */
    ],
  ],
];
