<?php
use CRM_Contactcats_ExtensionUtil as E;

return [
  'name' => 'ContactCategoryDefinition',
  'table' => 'civicrm_contact_category_definition',
  'class' => 'CRM_Contactcats_DAO_ContactCategoryDefinition',
  'getInfo' => fn() => [
    'title' => E::ts('Contact Category Definition'),
    'title_plural' => E::ts('Contact Category Definitions'),
    'description' => E::ts('Holds definition of a "Contact category"'),
    'log' => FALSE,
    'label_field' => 'label',
    'icon' => 'fa-tags',
  ],
  'getFields' => fn() => [
    'id' => [
      'title' => E::ts('ID'),
      'sql_type' => 'int unsigned',
      'input_type' => 'Number',
      'required' => TRUE,
      'description' => E::ts('Unique Contact Category Definition ID'),
      'primary_key' => TRUE,
      'auto_increment' => TRUE,
    ],
    'label' => [
      'title' => E::ts('Category name'),
      'sql_type' => 'varchar(255)',
      'input_type' => 'Text',
      'required' => TRUE,
      'input_attrs' => [
        'text_length' => 255,
        'label' => E::ts('Category name'),
      ],
    ],
    'description' => [
      'title' => E::ts('Description'),
      'sql_type' => 'text',
      'input_type' => 'TextArea',
      'required' => FALSE,
      'input_attrs' => [
        'note_columns' => 60,
        'note_rows' => 3,
        'label' => E::ts('Category description'),
      ],
    ],
    'search_type' => [
      'title' => E::ts('Definition type'),
      'sql_type' => 'varchar(12)',
      'input_type' => 'Select',
      'required' => TRUE,
      'default' => 'search',
      'pseudoconstant' => [
        'callback' => fn() => [
          // 'name' => 'title',
          'search' => E::ts('Search Kit search'),
          'group' => E::ts('Group'),
          'default' => E::ts('Default category'),
          // Future:
          // 'sql' => E::ts('SQL template'),
        ],
      ],
    ],
    'search_data' => [
      'title' => E::ts('JSON blob specifies particulars to for the search_type'),
      'description' => E::ts('Holds data specific to the search specification (e.g. a group ID when Group is selected).'),
      'sql_type' => 'text',
      'serialize' => CRM_Core_DAO::SERIALIZE_JSON,
    ],
    'color' => [
      'title' => E::ts('Colour for category label'),
      'sql_type' => 'varchar(7)',
      'input_type' => 'Color',
      'default' => '',
      'required' => TRUE,
    ],
    'icon' => [
      'title' => E::ts('Icon'),
      'sql_type' => 'varchar(64)',
      'default' => 'fa-circle-half-stroke',
      'required' => TRUE,
      'description' => E::ts('The name of a Font Awesome icon to use to represent this, e.g. fa-trophy'),
    ],
    'execution_order' => [
      'title' => E::ts('Execution order'),
      'description' => E::ts('The first category to match is assigned. Lower numbers are tested first.'),
      'sql_type' => 'int(1) unsigned',
      'default' => '10',
      'required' => TRUE,
    ],
    'presentation_order' => [
      'title' => E::ts('Presentation order'),
      'description' => E::ts('What order should these be presented in?'),
      'sql_type' => 'int(1) unsigned',
      'default' => '10',
      'required' => TRUE,
    ],
  ],
];
